@@ -27,7 +27,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.24';
+our $VERSION = '2.25';
 
 sub db {
   my $self = shift;
@@ -120,6 +120,9 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   drop table names;
   EOF
 
+  # Use migrations to drop and recreate the table
+  $pg->migrations->migrate(0)->migrate;
+
   # Insert a few rows
   my $db = $pg->db;
   $db->query('insert into names (name) values (?)', 'Sara');
@@ -466,6 +469,8 @@ Dan Book
 
 Hernan Lopes
 
+William Lindley
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
