@@ -42,7 +42,7 @@ sub _collect { Mojo::Collection->new(@_) }
 sub _expand {
   my ($self, @data) = @_;
 
-  return @data unless $data[0] && $self->{expand};
+  return @data unless $self->{expand} && $data[0];
   my ($idx, $name) = @$self{qw(idx name)};
   unless ($idx) {
     my $types = $self->sth->{pg_type};
@@ -133,7 +133,7 @@ Return column names as an array reference.
 
   $results = $results->expand;
 
-Decode C<json> and C<jsonb> fields automatically for all rows.
+Decode C<json> and C<jsonb> fields automatically to Perl values for all rows.
 
   # Expand JSON
   $results->expand->hashes->map(sub { $_->{foo}{bar} })->join("\n")->say;
